@@ -1,46 +1,45 @@
-## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-#     Copyright (C) 2012 - 2019  Reza Mohammadi                                                    |
-#                                                                                                  |
-#     This file is part of BDgraph package.                                                        |
-#                                                                                                  |
-#     BDgraph is free software: you can redistribute it and/or modify it under                     |
-#     the terms of the GNU General Public License as published by the Free                         |
-#     Software Foundation; see <https://cran.r-project.org/web/licenses/GPL-3>.                    |
-#                                                                                                  |
-#     Maintainer: Reza Mohammadi <a.mohammadi@uva.nl>                                              |
-## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-#     BDMCMC algorithm for graphical models based on marginal pseudo-likelihood                    |
-## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
+#     Copyright (C) 2012 - 2021  Reza Mohammadi                                |
+#                                                                              |
+#     This file is part of BDgraph package.                                    |
+#                                                                              |
+#     BDgraph is free software: you can redistribute it and/or modify it under |
+#     the terms of the GNU General Public License as published by the Free     |
+#     Software Foundation; see <https://cran.r-project.org/web/licenses/GPL-3>.|
+#                                                                              |
+#     Maintainer: Reza Mohammadi <a.mohammadi@uva.nl>                          |
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
+#     BDMCMC algorithm for graphical models based on marginal pseudo-likelihood
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
 
 bdgraph.mpl = function( data, n = NULL, method = "ggm", transfer = TRUE, algorithm = "bdmcmc", 
 					iter = 5000, burnin = iter / 2, g.prior = 0.5, g.start = "empty", 
-					jump = NULL, alpha = 0.5, save = FALSE, print = 1000, 
+					jump = NULL, alpha = 0.5, save = FALSE, 
 					cores = NULL, operator = "or" )
 {
-    if( iter < burnin ) stop( " Number of iteration must be more than number of burn-in" )
+    if( iter < burnin ) stop( " 'iter' must be higher than 'burnin'" )
     burnin = floor( burnin )
-    if( print > iter ) print = iter
-    
+     
     cores = BDgraph::get_cores( cores = cores )
     
-	if( class( data ) == "sim" ) data <- data $ data
+	if( inherits( data, "sim" ) ) data <- data $ data
 	colnames_data = colnames( data )
 
-	if( !is.matrix( data ) & !is.data.frame( data ) ) stop( " Data should be a matrix or dataframe" )
+	if( !is.matrix( data ) & !is.data.frame( data ) ) stop( "Data must be a matrix or dataframe" )
 	if( is.data.frame( data ) ) data <- data.matrix( data )
 	
-	if( any( is.na( data ) ) ) stop( " This method does not deal with missing values. You could try bdgraph() function with option method = gcgm" )	
+	if( any( is.na( data ) ) ) stop( "'bdgraph.mpl()' does not deal with missing values. You could use 'bdgraph()' function with option method = 'gcgm'" )	
 		
 	p <- ncol( data )
-	if( p < 3 ) stop( " Number of variables/nodes ('p') must be more than 2" )
+	if( p < 3 ) stop( "Number of variables/nodes ('p') must be more than 2" )
 	if( is.null( n ) ) n <- nrow( data )
 
 	if( method == "ggm" ) 
 	{
 		if( isSymmetric( data ) )
 		{
-			if ( is.null( n ) ) stop( " Please specify the number of observations 'n'" )
-			cat( " Input is identified as the covriance matrix. \n" )
+			if ( is.null( n ) ) stop( "Please specify the number of observations 'n'" )
+			cat( "Input is identified as the covariance matrix \n" )
 			S <- data
 		}else{
  			S <- t( data ) %*% data
@@ -62,7 +61,7 @@ bdgraph.mpl = function( data, n = NULL, method = "ggm", transfer = TRUE, algorit
 	}
 	
 	if( method == "dgm-binary" )
-		if( ( min( data ) != 0 ) || ( max( data ) != 1 ) ) stop( " For the case 'method = dgm-binary', data must be binary 0 or 1" )
+		if( ( min( data ) != 0 ) || ( max( data ) != 1 ) ) stop( "For the case 'method = \"dgm-binary\"', data must be binary, 0 or 1" )
 	
 	g_prior = BDgraph::get_g_prior( g.prior = g.prior, p = p )
 	G       = BDgraph::get_g_start( g.start = g.start, g_prior = g_prior, p = p )
@@ -93,16 +92,15 @@ bdgraph.mpl = function( data, n = NULL, method = "ggm", transfer = TRUE, algorit
 	
 	if( is.null( jump ) ) jump = 1
 	
-	if( ( p < 10 ) && ( jump > 1 ) )      cat( " WARNING: the value of jump should be 1 " )
-	if( jump > min( p, sqrt( p * 11 ) ) ) cat( " WARNING: the value of jump should be smaller " )
+	if( ( p < 10 ) && ( jump > 1 ) )      cat( " WARNING: the value of jump should be 1. " )
+	if( jump > min( p, sqrt( p * 11 ) ) ) cat( " WARNING: the value of jump should be smaller. " )
 	
 	if( algorithm != "hc" )
-	{
-	    mes <- paste( c( iter, " iteration is started.                    " ), collapse = "" )
-	    cat( mes, "\r" )
-	}
+		cat( paste( c( iter, " MCMC sampling ... in progress: \n" ), collapse = "" ) ) 
+
+    print = floor( iter / 20 )
 	
-	# - - - main BDMCMC algorithms implemented in C++ - - - - - - - - - - - - - - - - - - - - - - -|
+	# - - - main BDMCMC algorithms implemented in C++ - - - - - - - - - - - - -|
 	if( save == TRUE )
 	{
 		if( ( method == "ggm" ) && ( algorithm == "rjmcmc" ) )
@@ -232,7 +230,7 @@ bdgraph.mpl = function( data, n = NULL, method = "ggm", transfer = TRUE, algorit
 						p_links = as.double(p_links), as.integer(jump), as.integer(print), PACKAGE = "BDgraph" )
 		}				
 	}
-	# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -|
+	# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -|
 
 	if( algorithm != "hc" )
 	{
@@ -271,10 +269,10 @@ bdgraph.mpl = function( data, n = NULL, method = "ggm", transfer = TRUE, algorit
 		colnames( selected_graph ) = colnames_data[ 1:p ]
 		output = selected_graph
 	}
-	# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -|
+	# - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -|
 	
 	class( output ) = "bdgraph"
 	return( output )   
 }
            
-## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
+## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
