@@ -1,5 +1,5 @@
 ## - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - |
-#     Copyright (C) 2012 - 2020  Reza Mohammadi                                |
+#     Copyright (C) 2012 - 2021  Reza Mohammadi                                |
 #                                                                              |
 #     This file is part of BDgraph package.                                    |
 #                                                                              |
@@ -15,14 +15,14 @@
 plinks = function( bdgraph.obj, round = 2, burnin = NULL )
 {
     if( ( !inherits( bdgraph.obj, "bdgraph" ) ) && ( !inherits( bdgraph.obj, "ssgraph" ) ) )
-        stop( "'bdgraph.obj' must be an object from functions 'bdgraph()', 'bdgraph.mpl()', or 'ssgraph()'." )
+        stop( "'bdgraph.obj' must be an object from functions 'bdgraph()', 'bdgraph.mpl()', or 'ssgraph()'" )
     
     if( inherits( bdgraph.obj, "bdgraph" ) )
     {
         if( is.null( bdgraph.obj $ sample_graphs ) )
-    	{
-    		p_links = bdgraph.obj $ p_links
-    	}else{
+    	  {
+    		    p_links = bdgraph.obj $ p_links
+    	  }else{
     		
     		p     <- nrow( bdgraph.obj $ last_graph )
     		vec_G <- numeric( length = ( p * ( p - 1 ) / 2 ) )
